#include   <stdio.h>
#include   <stdlib.h>
#include   <visa.h>
#include   "age5270.h"
 
void check_err (ViSession vi, ViStatus ret) {
 ViInt32    	inst_err;
 ViChar		    err_msg[256];
 if(VI_SUCCESS > ret) {
     if ( age5270_INSTR_ERROR_DETECTED == ret ) {
         age5270_error_query(vi, &inst_err, err_msg);
         printf("Instrument Error: %ld\n %s\n", inst_err, err_msg);
	 }
     else {
         age5270_error_message(vi, ret, err_msg);
         printf("Driver Error: %ld\n %s\n", ret, err_msg);
	 }
 }
}

void perform_meas (ViSession vi, ViStatus ret) /* 1 */
{
ViInt32 emitter; /* 3 */
ViInt32 base;
ViInt32 collector;
emitter = 1; /* SMU1 */
base = 2; /* SMU2 */
collector = 4; /* SMU4 */ /* 8 */
ret = age5270_setSwitch(vi, emitter, 1); /* 10 */
ret = age5270_setSwitch(vi, base, 1);
ret = age5270_setSwitch(vi, collector, 1);
check_err (vi, ret); /* 13 */
ViReal64 vc; /* 15 */
ViReal64 vb;
ViReal64 iccomp;
ViReal64 ibcomp;
vc = 3;
iccomp = 1;
vb = 0.7;
ibcomp = 0.01;
ViInt32 mch[3];
ViInt32 mode[2];
ViReal64 range[2];
ViReal64 md[2];
ViInt32 st[2];
ViReal64 tm[2]; /* 29 */
mch[0] = collector; /* 31 */
mch[1] = base;
mch[2] = 0;
mode[0] = 1;
mode[1] = 1;
range[0] = 0;
range[1] = 0;
ret = age5270_resetTimestamp(vi); /* 38 */
ret = age5270_force(vi, emitter, age5270_VF_MODE, 0, 0, 0.2, 0);
ret = age5270_force(vi, base, age5270_VF_MODE, 0, vb, ibcomp, 0);
ret = age5270_force(vi, collector, age5270_VF_MODE, 0, vc, iccomp, 0);
check_err (vi, ret); /* 42 */
ret = age5270_measureM(vi, mch, mode, range, &md[0], &st[0], &tm[0]);
check_err (vi, ret); /* 45 */
ret = age5270_zeroOutput(vi, age5270_CH_ALL); /* 47 */
check_err (vi, ret); /* 48 */
printf("Ic = %8.6f mA (Time: %8.6f sec)\n", md[0] * 1000, tm[0]);
printf("Ib = %8.6f mA (Time: %8.6f sec)\n", md[1] * 1000, tm[1]);
printf("hfe = %8.6f \n", md[0]/md[1]); /* 52 */
ret = age5270_setSwitch(vi, age5270_CH_ALL, 0); /* 54 */
check_err (vi, ret); /* 55 */
}
 
ViStatus main ( )
{
 ViStatus    ret;
 ViSession   vi;
 ViChar      err_msg[256];

 /* Starting the session. */
 ret = age5270_init("GPIB::17::INSTR", VI_TRUE, VI_TRUE, &vi);
 if ( ( ret < VI_SUCCESS ) || ( vi == VI_NULL ) ) {
     printf("Initialization failure.\n Status code: %d.\n", ret);
     if ( vi != VI_NULL ) {
         age5270_error_message(vi, ret, err_msg);
         printf("Error: %ld\n %s\n", ret, err_msg);
	 }
     exit (ret);
 }
 ret = age5270_reset(vi);              	       /* Resets E5270              */
 ret = age5270_timeOut(vi, 60000); 	           /* sets 60 second timeout    */
 ret = age5270_errorQueryDetect(vi, VI_TRUE);  /* Turns on error detection. */
 
 perform_meas (vi, ret);
 ret = age5270_cmd(vi, "aa");
 check_err(vi, ret);
 
 /* Closing the session. */
 ret = age5270_close(vi);
 check_err(vi, ret);

 return VI_SUCCESS;
}